==> zio-aws-textract_3-5.17.104.7-sources.jar: zio/aws/textract/model/Point.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class Point(x: Option[Float] = None, y: Option[Float] = None) {
  def buildAwsValue(): software.amazon.awssdk.services.textract.model.Point = {
    import Point.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.Point
      .builder()
      .optionallyWith(x.map(value => value: java.lang.Float))(_.x)
      .optionallyWith(y.map(value => value: java.lang.Float))(_.y)
      .build()
  }
  def asReadOnly: zio.aws.textract.model.Point.ReadOnly =
    zio.aws.textract.model.Point.wrap(buildAwsValue())
}
object Point {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.textract.model.Point] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.Point =
      zio.aws.textract.model.Point(x.map(value => value), y.map(value => value))
    def x: Option[Float]
    def y: Option[Float]
    def getX: ZIO[Any, AwsError, Float] = AwsError.unwrapOptionField("x", x)
    def getY: ZIO[Any, AwsError, Float] = AwsError.unwrapOptionField("y", y)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.Point
  ) extends zio.aws.textract.model.Point.ReadOnly {
    override val x: Option[Float] =
      scala.Option(impl.x()).map(value => value: Float)
    override val y: Option[Float] =
      scala.Option(impl.y()).map(value => value: Float)
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.Point
  ): zio.aws.textract.model.Point.ReadOnly = new Wrapper(impl)
}

==> zio-aws-textract_3-7.21.15.12-sources.jar: zio/aws/textract/model/Point.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class Point(
    x: Optional[Float] = Optional.Absent,
    y: Optional[Float] = Optional.Absent
) {
  def buildAwsValue(): software.amazon.awssdk.services.textract.model.Point = {
    import Point.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.Point
      .builder()
      .optionallyWith(x.map(value => value: java.lang.Float))(_.x)
      .optionallyWith(y.map(value => value: java.lang.Float))(_.y)
      .build()
  }
  def asReadOnly: zio.aws.textract.model.Point.ReadOnly =
    zio.aws.textract.model.Point.wrap(buildAwsValue())
}
object Point {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.textract.model.Point] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.Point =
      zio.aws.textract.model.Point(x.map(value => value), y.map(value => value))
    def x: Optional[Float]
    def y: Optional[Float]
    def getX: ZIO[Any, AwsError, Float] = AwsError.unwrapOptionField("x", x)
    def getY: ZIO[Any, AwsError, Float] = AwsError.unwrapOptionField("y", y)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.Point
  ) extends zio.aws.textract.model.Point.ReadOnly {
    override val x: Optional[Float] = zio.aws.core.internal
      .optionalFromNullable(impl.x())
      .map(value => value: Float)
    override val y: Optional[Float] = zio.aws.core.internal
      .optionalFromNullable(impl.y())
      .map(value => value: Float)
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.Point
  ): zio.aws.textract.model.Point.ReadOnly = new Wrapper(impl)
}
